# This spec file is derived from the RHEL8 lmdb spec file.  They should be kept
# in sync over time.
# https://git.centos.org/rpms/lmdb/blob/c8/f/SPECS/lmdb.spec

# The files themselves are in several subdirectories and need to be prefixed wit this.
%global archive_path libraries/liblmdb

Name:           lmdb-epel
Version:        0.9.24
Release:        1%{?dist}
Summary:        Alternative lmdb package for EPEL

License:        OpenLDAP
URL:            http://symas.com/mdb/
Source0:        https://github.com/LMDB/lmdb/archive/LMDB_%{version}.tar.gz#/lmdb-LMDB_%{version}.tar.gz
Source1:        lmdb.pc.in

BuildRequires: make
BuildRequires: gcc
BuildRequires: doxygen

# Patch description in the corresponding file
Patch0: lmdb-make.patch
Patch1: lmdb-s390-check.patch
Patch2: lmdb-covscan.patch

%description
Alternative lmdb package to provide the subpackages that are filtered out of
RHEL.


%package -n     lmdb
Summary:        Memory-mapped key-value database
Requires:       lmdb-libs%{?_isa} = %{version}-%{release}

%description -n lmdb
LMDB is an ultra-fast, ultra-compact key-value embedded data
store developed by Symas for the OpenLDAP Project. By using memory-mapped files,
it provides the read performance of a pure in-memory database while still
offering the persistence of standard disk-based databases, and is only limited
to the size of the virtual address space.

%package -n     lmdb-devel
Summary:        Development files for lmdb
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description -n lmdb-devel
The lmdb-devel package contains libraries and header files for
developing applications that use lmdb.

%package -n     lmdb-doc
Summary:        Documentation files for lmdb
BuildArch:      noarch

%description -n lmdb-doc
The lmdb-doc package contains automatically generated documentation for %{name}.


%prep
%setup -q -n lmdb-LMDB_%{version}
%patch0 -p1 -b .make
%patch1 -p1 -b .s390-check
%patch2 -p1 -b .covscan

%build
pushd %{archive_path}
make LDFLAGS="%{build_ldflags}" XCFLAGS="%{optflags}" %{?_smp_mflags}
# Build doxygen documentation
doxygen
# remove unpackaged files
rm -f Doxyfile
rm -rf man # Doxygen generated manpages
popd

%install
pushd %{archive_path}
# make install expects existing directory tree
mkdir -m 0755 -p %{buildroot}{%{_bindir},%{_includedir}}
mkdir -m 0755 -p %{buildroot}{%{_libdir}/pkgconfig,%{_mandir}/man1}
make DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} mandir=%{_mandir} install
popd

# Install pkgconfig file
sed -e 's:@PREFIX@:%{_prefix}:g' \
    -e 's:@EXEC_PREFIX@:%{_exec_prefix}:g' \
    -e 's:@LIBDIR@:%{_libdir}:g' \
    -e 's:@INCLUDEDIR@:%{_includedir}:g' \
    -e 's:@PACKAGE_VERSION@:%{version}:g' \
    %{SOURCE1} >lmdb.pc
install -Dpm 0644 -t %{buildroot}%{_libdir}/pkgconfig lmdb.pc

# remove files shipped in RHEL
rm -f %{buildroot}%{_libdir}/liblmdb.so.0.0.0


%files -n lmdb
%{_bindir}/*
%{_mandir}/man1/*

%files -n lmdb-devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n lmdb-doc
%doc %{archive_path}/html
%doc %{archive_path}/COPYRIGHT
%doc %{archive_path}/CHANGES
%license %{archive_path}/LICENSE


%changelog
* Thu Jun 17 2021 Carl George <carl@george.computer> - 0.9.24-1
- Convert RHEL8 lmdb to lmdb-epel, with all subpackages except lmdb-libs
- Related: rhbz#1833564
- Related: rhbz#1972979

* Thu May 07 2020 Radovan Sroka <rsroka@redhat.com> - 0.9.24-1
- RHEL 8.3.0 ERRATUM
- rebase to 0.9.24
- Resolves: rhbz#1817421

* Tue Jun 18 2019 Radovan Sroka <rsroka@redhat.com> - 0.9.23-5
- fixed resolves from RPMDIFF
- fixed some covscan issues

* Wed Jun 12 2019 Radovan Sroka <rsroka@redhat.com> - 0.9.23-4
- propagate ldflags for makefile
- added explicit Requires for -libs

* Wed May 15 2019 Radovan Sroka <rsroka@redhat.com> - 0.9.23-3
- rebuild

* Mon Apr 29 2019 Radovan Sroka <rsroka@redhat.com> - 0.9.23-2
- Initial Package
- Resolves: rhbz#1692264
